@@ -2,9 +2,13 @@
 # -*- encoding: utf-8 -*-
 
 
-import re
-from .javalang.tokenizer import JavaToken
+import sys
+import os
+sys.path.append(os.path.dirname(__file__))
+
 from typing import List
+from .javalang.tokenizer import JavaToken
+
 
 
 class CodeCleaner:
